@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2005, 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 2003-2005, 2007-2012, 2014-2016 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -17,6 +18,7 @@
 
 #ifndef _MAILUTILS_GSASL_H
 #define _MAILUTILS_GSASL_H
+#include <mailutils/cli.h>
 
 struct mu_gsasl_module_data
 {
@@ -27,16 +29,13 @@ struct mu_gsasl_module_data
   char *anon_user;
   char *cram_md5_pwd;
 };
+extern struct mu_gsasl_module_data mu_gsasl_module_data;
 
 int mu_gsasl_enabled (void);
 
 #ifdef WITH_GSASL
 #include <gsasl.h>
 
-int mu_gsasl_module_init (enum mu_gocs_op, void *);
-extern struct mu_gsasl_module_data mu_gsasl_module_data;
-
-
 int gsasl_encoder_stream (mu_stream_t *pstr, mu_stream_t transport,
 			  Gsasl_session *ctx, int flags);
 int gsasl_decoder_stream (mu_stream_t *pstr, mu_stream_t transport,
