@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004, 2007, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2007, 2011-2012, 2014-2016 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -12,9 +13,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library; if not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA */
+   Public License along with this library.  If not, see
+   <http://www.gnu.org/licenses/>. */
 
 #ifndef _MAILUTILS_SYS_NNTP_H
 #define _MAILUTILS_SYS_NNTP_H
@@ -142,8 +142,6 @@ struct _mu_nntp
 
     unsigned timeout;  /* Default is 10 minutes.  */
 
-    mu_debug_t debug; /* debugging trace.  */
-
     enum mu_nntp_state state;  /* Indicate the state of the running command.  */
 
     mu_stream_t carrier; /* TCP Connection.  */
