@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2007, 2009-2012 Free Software Foundation,
-   Inc.
+   Copyright (C) 1999-2001, 2007, 2009-2012, 2014-2016 Free Software
+   Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,13 +20,17 @@
 #endif
 #include <time.h>
 
-/* Convert time 0 at UTC to our localtime, that tells us the offset
-   of our current timezone from UTC. */
+#define TMSEC(t) (((t)->tm_hour * 60 + (t)->tm_min) * 60 + (t)->tm_sec)
+
+/* Returns the offset of our timezone from UTC, in seconds. */
 int
 mu_utc_offset (void)
 {
-  time_t t = 0;
-  struct tm *tm = gmtime (&t);
-
-  return - mktime (tm);
+  time_t t = time (NULL);
+  struct tm ltm = *localtime (&t);
+  struct tm gtm = *gmtime (&t);
+  int d = TMSEC (&ltm) - TMSEC (&gtm);
+  if (!(ltm.tm_year = gtm.tm_year && ltm.tm_mon == gtm.tm_mon))
+    d += 86400;
+  return d;
 }
