@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2004-2012 Free Software Foundation, Inc.
+   Copyright (C) 1999-2002, 2004-2012, 2014-2016 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -86,6 +87,9 @@ fd_open (struct _mu_stream *str)
   /* Map the flags to the system equivalent.  */
   if ((fstr->stream.flags & MU_STREAM_RDWR) == MU_STREAM_RDWR)
     oflg = O_RDWR;
+  else if ((fstr->stream.flags & (MU_STREAM_READ|MU_STREAM_APPEND)) ==
+	   (MU_STREAM_READ|MU_STREAM_APPEND))
+    oflg = O_RDWR;
   else if (fstr->stream.flags & (MU_STREAM_WRITE|MU_STREAM_APPEND))
     oflg = O_WRONLY;
   else /* default */
@@ -177,13 +181,13 @@ fd_ioctl (struct _mu_stream *str, int code, int opcode, void *ptr)
 	{
 	case MU_IOCTL_OP_GET:
 	  ptrans = ptr;
-	  ptrans[0] = (mu_transport_t) fstr->fd;
+	  ptrans[0] = (mu_transport_t) (intptr_t) fstr->fd;
 	  ptrans[1] = NULL;
 	  break;
 
 	case MU_IOCTL_OP_SET:
 	  ptrans = ptr;
-	  fstr->fd = (int) ptrans[0];
+	  fstr->fd = (int) (intptr_t) ptrans[0];
 	  break;
 	}
       break;
