@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2001, 2003, 2005, 2007, 2009-2012, 2014-2015 Free
+   Copyright (C) 1999-2001, 2003, 2005, 2007, 2009-2012, 2014-2016 Free
    Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
@@ -654,7 +654,7 @@ pop_header_blurb (mu_stream_t stream, size_t maxlines,
   size_t n;
   size_t nlines = 0;
   
-  status = mu_opool_create (&opool, 0);
+  status = mu_opool_create (&opool, MU_OPOOL_DEFAULT);
   if (status)
     return status;
       
