@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2005-2007, 2009-2012, 2014-2015 Free
+   Copyright (C) 1999-2002, 2005-2007, 2009-2012, 2014-2016 Free
    Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -256,8 +256,8 @@ extern int mail_header_is_unfoldable (const char *str);
 extern int mail_mbox_close (void);
 extern char *mail_expand_name (const char *name);
 
-extern void send_append_header (char *text);
-extern void send_append_header2 (char *name, char *value, int mode);
+extern void send_append_header (char const *text);
+extern void send_append_header2 (char const *name, char const *value, int mode);
 extern int send_attach_file_default (const char *name);
 
 extern int escape_check_args (int argc, char **argv, int minargs, int maxargs);
@@ -288,6 +288,15 @@ extern int escape_attach (int argc, char **argv, compose_env_t *env);
 extern int escape_remove_attachment (int argc, char **argv,
 				     compose_env_t *env);
 
+enum
+  {
+    parse_headers_ok,
+    parse_headers_error,
+    parse_headers_fatal
+  };
+
+extern int parse_headers (mu_stream_t input, compose_env_t *env);
+
 /* Cursor */
 extern void set_cursor (unsigned value);
 extern size_t get_cursor (void);
