@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,18 +58,15 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 0
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "mh_alias.y"
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2007, 2010-2012, 2014-2015 Free Software
+   Copyright (C) 2003-2007, 2010-2012, 2014-2016 Free Software
    Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -163,9 +160,8 @@ int ali_yyerror (char *s);
 int ali_yylex (void);
 
 
-
-/* Line 268 of yacc.c  */
-#line 169 "mh_alias_gram.c"
+/* Line 371 of yacc.c  */
+#line 165 "mh_alias_gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -175,11 +171,6 @@ int ali_yylex (void);
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -188,11 +179,17 @@ int ali_yylex (void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int ali_yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -208,12 +205,10 @@ int ali_yylex (void);
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 98 "mh_alias.y"
 
   char *string;
@@ -221,21 +216,36 @@ typedef union YYSTYPE
   struct mh_alias *alias;
 
 
-
-/* Line 295 of yacc.c  */
-#line 227 "mh_alias_gram.c"
+/* Line 387 of yacc.c  */
+#line 221 "mh_alias_gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define ali_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+extern YYSTYPE ali_yylval;
+
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int ali_yyparse (void *YYPARSE_PARAM);
+#else
+int ali_yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int ali_yyparse (void);
+#else
+int ali_yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 239 "mh_alias_gram.c"
+/* Line 390 of yacc.c  */
+#line 249 "mh_alias_gram.c"
 
 #ifdef short
 # undef short
@@ -288,24 +298,24 @@ typedef short int ali_yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -535,7 +545,7 @@ static const ali_yytype_uint8 ali_yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const ali_yytname[] =
@@ -619,10 +629,10 @@ static const ali_yytype_uint8 ali_yytable[] =
       28,     0,    12,    30,     0,    25
 };
 
-#define ali_yypact_value_is_default(ali_yystate) \
-  ((ali_yystate) == (-8))
+#define ali_yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-8)))
 
-#define ali_yytable_value_is_error(ali_yytable_value) \
+#define ali_yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const ali_yytype_int8 ali_yycheck[] =
@@ -686,46 +696,18 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (YYID (0))
-#endif
-
-
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `ali_yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX ali_yylex (YYLEX_PARAM)
 #else
@@ -788,7 +770,7 @@ ali_yy_symbol_value_print (ali_yyoutput, ali_yytype, ali_yyvaluep)
   switch (ali_yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1030,7 +1012,6 @@ ali_yysyntax_error (YYSIZE_T *ali_yymsg_alloc, char **ali_yymsg,
 {
   YYSIZE_T ali_yysize0 = ali_yytnamerr (YY_NULL, ali_yytname[ali_yytoken]);
   YYSIZE_T ali_yysize = ali_yysize0;
-  YYSIZE_T ali_yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *ali_yyformat = YY_NULL;
@@ -1093,11 +1074,13 @@ ali_yysyntax_error (YYSIZE_T *ali_yymsg_alloc, char **ali_yymsg,
                     break;
                   }
                 ali_yyarg[ali_yycount++] = ali_yytname[ali_yyx];
-                ali_yysize1 = ali_yysize + ali_yytnamerr (YY_NULL, ali_yytname[ali_yyx]);
-                if (! (ali_yysize <= ali_yysize1
-                       && ali_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                ali_yysize = ali_yysize1;
+                {
+                  YYSIZE_T ali_yysize1 = ali_yysize + ali_yytnamerr (YY_NULL, ali_yytname[ali_yyx]);
+                  if (! (ali_yysize <= ali_yysize1
+                         && ali_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  ali_yysize = ali_yysize1;
+                }
               }
         }
     }
@@ -1117,10 +1100,12 @@ ali_yysyntax_error (YYSIZE_T *ali_yymsg_alloc, char **ali_yymsg,
 # undef YYCASE_
     }
 
-  ali_yysize1 = ali_yysize + ali_yystrlen (ali_yyformat);
-  if (! (ali_yysize <= ali_yysize1 && ali_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  ali_yysize = ali_yysize1;
+  {
+    YYSIZE_T ali_yysize1 = ali_yysize + ali_yystrlen (ali_yyformat);
+    if (! (ali_yysize <= ali_yysize1 && ali_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    ali_yysize = ali_yysize1;
+  }
 
   if (*ali_yymsg_alloc < ali_yysize)
     {
@@ -1180,32 +1165,27 @@ ali_yydestruct (ali_yymsg, ali_yytype, ali_yyvaluep)
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int ali_yyparse (void *YYPARSE_PARAM);
-#else
-int ali_yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int ali_yyparse (void);
-#else
-int ali_yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int ali_yychar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE ali_yylval;
+YYSTYPE ali_yylval YY_INITIAL_VALUE(ali_yyval_default);
 
 /* Number of syntax errors so far.  */
 int ali_yynerrs;
@@ -1263,7 +1243,7 @@ ali_yyparse ()
   int ali_yyn;
   int ali_yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int ali_yytoken;
+  int ali_yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE ali_yyval;
@@ -1281,9 +1261,8 @@ ali_yyparse ()
      Keep to zero when no symbol should be popped.  */
   int ali_yylen = 0;
 
-  ali_yytoken = 0;
-  ali_yyss = ali_yyssa;
-  ali_yyvs = ali_yyvsa;
+  ali_yyssp = ali_yyss = ali_yyssa;
+  ali_yyvsp = ali_yyvs = ali_yyvsa;
   ali_yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1292,14 +1271,6 @@ ali_yyparse ()
   ali_yyerrstatus = 0;
   ali_yynerrs = 0;
   ali_yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  ali_yyssp = ali_yyss;
-  ali_yyvsp = ali_yyvs;
-
   goto ali_yysetstate;
 
 /*------------------------------------------------------------.
@@ -1440,7 +1411,9 @@ ali_yybackup:
   ali_yychar = YYEMPTY;
 
   ali_yystate = ali_yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++ali_yyvsp = ali_yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto ali_yynewstate;
 
@@ -1477,8 +1450,7 @@ ali_yyreduce:
   switch (ali_yyn)
     {
         case 7:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 119 "mh_alias.y"
     {
 		 if (!alias_list)
@@ -1488,8 +1460,7 @@ ali_yyreduce:
     break;
 
   case 8:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 125 "mh_alias.y"
     {
 		 mu_list_append (alias_list, (ali_yyvsp[(3) - (3)].alias));
@@ -1497,15 +1468,13 @@ ali_yyreduce:
     break;
 
   case 11:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 134 "mh_alias.y"
     { ali_verbatim (1); }
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 135 "mh_alias.y"
     {
 		 ali_verbatim (0);
@@ -1517,15 +1486,13 @@ ali_yyreduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 142 "mh_alias.y"
     { ali_verbatim (1); }
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 143 "mh_alias.y"
     {
 		 ali_verbatim (0);
@@ -1537,8 +1504,7 @@ ali_yyreduce:
     break;
 
   case 16:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 154 "mh_alias.y"
     {
 		 (ali_yyval.list) = unix_group_to_list ((ali_yyvsp[(2) - (2)].string));
@@ -1547,8 +1513,7 @@ ali_yyreduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 159 "mh_alias.y"
     {
 		 (ali_yyval.list) = unix_gid_to_list ((ali_yyvsp[(2) - (2)].string));
@@ -1557,8 +1522,7 @@ ali_yyreduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 164 "mh_alias.y"
     {
 		 (ali_yyval.list) = unix_passwd_to_list ();
@@ -1566,8 +1530,7 @@ ali_yyreduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 170 "mh_alias.y"
     {
 		 (ali_yyval.list) = list_create_or_die ();
@@ -1576,8 +1539,7 @@ ali_yyreduce:
     break;
 
   case 20:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 175 "mh_alias.y"
     {
 		 mu_list_append ((ali_yyvsp[(1) - (3)].list), (ali_yyvsp[(3) - (3)].string));
@@ -1586,8 +1548,7 @@ ali_yyreduce:
     break;
 
   case 21:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 182 "mh_alias.y"
     {
 		 (ali_yyval.string) = ali_list_to_string (&(ali_yyvsp[(1) - (1)].list));
@@ -1595,8 +1556,7 @@ ali_yyreduce:
     break;
 
   case 22:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 188 "mh_alias.y"
     {
 		 mu_list_create(&(ali_yyval.list));
@@ -1605,8 +1565,7 @@ ali_yyreduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 193 "mh_alias.y"
     {
 		 mu_list_append((ali_yyvsp[(1) - (2)].list), (ali_yyvsp[(2) - (2)].string));
@@ -1615,9 +1574,8 @@ ali_yyreduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1621 "mh_alias_gram.c"
+/* Line 1792 of yacc.c  */
+#line 1579 "mh_alias_gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter ali_yychar, and that requires
@@ -1780,7 +1738,9 @@ ali_yyerrlab1:
       YY_STACK_PRINT (ali_yyss, ali_yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++ali_yyvsp = ali_yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -1846,8 +1806,7 @@ ali_yyreturn:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 199 "mh_alias.y"
 
 
@@ -2167,4 +2126,3 @@ mh_read_aliases ()
   mh_alias_read (DEFAULT_ALIAS_FILE, 0);
   return 0;
 }
-
