@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,18 +58,15 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 0
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "mimetypes.y"
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2005, 2007, 2009-2012, 2014-2015 Free Software
+   Copyright (C) 2005, 2007, 2009-2012, 2014-2016 Free Software
    Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
@@ -174,9 +171,8 @@ struct rule_tab
 static mu_list_t rule_list;
 
 
-
-/* Line 268 of yacc.c  */
-#line 180 "mimetypes-gram.c"
+/* Line 371 of yacc.c  */
+#line 176 "mimetypes-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -186,11 +182,6 @@ static mu_list_t rule_list;
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -199,11 +190,17 @@ static mu_list_t rule_list;
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int mimetypes_yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -227,12 +224,10 @@ static mu_list_t rule_list;
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 120 "mimetypes.y"
 
   struct mimetypes_string string;
@@ -241,21 +236,36 @@ typedef union YYSTYPE
   struct node *node;
 
 
-
-/* Line 295 of yacc.c  */
-#line 247 "mimetypes-gram.c"
+/* Line 387 of yacc.c  */
+#line 241 "mimetypes-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define mimetypes_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+extern YYSTYPE mimetypes_yylval;
+
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int mimetypes_yyparse (void *YYPARSE_PARAM);
+#else
+int mimetypes_yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int mimetypes_yyparse (void);
+#else
+int mimetypes_yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 259 "mimetypes-gram.c"
+/* Line 390 of yacc.c  */
+#line 269 "mimetypes-gram.c"
 
 #ifdef short
 # undef short
@@ -308,24 +318,24 @@ typedef short int mimetypes_yytype_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -556,7 +566,7 @@ static const mimetypes_yytype_uint8 mimetypes_yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const mimetypes_yytname[] =
@@ -644,10 +654,10 @@ static const mimetypes_yytype_int8 mimetypes_yytable[] =
       12,     2,    14,     0,    21
 };
 
-#define mimetypes_yypact_value_is_default(mimetypes_yystate) \
-  ((mimetypes_yystate) == (-13))
+#define mimetypes_yypact_value_is_default(Yystate) \
+  (!!((Yystate) == (-13)))
 
-#define mimetypes_yytable_value_is_error(mimetypes_yytable_value) \
+#define mimetypes_yytable_value_is_error(Yytable_value) \
   YYID (0)
 
 static const mimetypes_yytype_int8 mimetypes_yycheck[] =
@@ -714,46 +724,18 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (YYID (0))
-#endif
-
-
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `mimetypes_yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX mimetypes_yylex (YYLEX_PARAM)
 #else
@@ -816,7 +798,7 @@ mimetypes_yy_symbol_value_print (mimetypes_yyoutput, mimetypes_yytype, mimetypes
   switch (mimetypes_yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1058,7 +1040,6 @@ mimetypes_yysyntax_error (YYSIZE_T *mimetypes_yymsg_alloc, char **mimetypes_yyms
 {
   YYSIZE_T mimetypes_yysize0 = mimetypes_yytnamerr (YY_NULL, mimetypes_yytname[mimetypes_yytoken]);
   YYSIZE_T mimetypes_yysize = mimetypes_yysize0;
-  YYSIZE_T mimetypes_yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *mimetypes_yyformat = YY_NULL;
@@ -1121,11 +1102,13 @@ mimetypes_yysyntax_error (YYSIZE_T *mimetypes_yymsg_alloc, char **mimetypes_yyms
                     break;
                   }
                 mimetypes_yyarg[mimetypes_yycount++] = mimetypes_yytname[mimetypes_yyx];
-                mimetypes_yysize1 = mimetypes_yysize + mimetypes_yytnamerr (YY_NULL, mimetypes_yytname[mimetypes_yyx]);
-                if (! (mimetypes_yysize <= mimetypes_yysize1
-                       && mimetypes_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                mimetypes_yysize = mimetypes_yysize1;
+                {
+                  YYSIZE_T mimetypes_yysize1 = mimetypes_yysize + mimetypes_yytnamerr (YY_NULL, mimetypes_yytname[mimetypes_yyx]);
+                  if (! (mimetypes_yysize <= mimetypes_yysize1
+                         && mimetypes_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  mimetypes_yysize = mimetypes_yysize1;
+                }
               }
         }
     }
@@ -1145,10 +1128,12 @@ mimetypes_yysyntax_error (YYSIZE_T *mimetypes_yymsg_alloc, char **mimetypes_yyms
 # undef YYCASE_
     }
 
-  mimetypes_yysize1 = mimetypes_yysize + mimetypes_yystrlen (mimetypes_yyformat);
-  if (! (mimetypes_yysize <= mimetypes_yysize1 && mimetypes_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  mimetypes_yysize = mimetypes_yysize1;
+  {
+    YYSIZE_T mimetypes_yysize1 = mimetypes_yysize + mimetypes_yystrlen (mimetypes_yyformat);
+    if (! (mimetypes_yysize <= mimetypes_yysize1 && mimetypes_yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    mimetypes_yysize = mimetypes_yysize1;
+  }
 
   if (*mimetypes_yymsg_alloc < mimetypes_yysize)
     {
@@ -1208,32 +1193,27 @@ mimetypes_yydestruct (mimetypes_yymsg, mimetypes_yytype, mimetypes_yyvaluep)
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int mimetypes_yyparse (void *YYPARSE_PARAM);
-#else
-int mimetypes_yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int mimetypes_yyparse (void);
-#else
-int mimetypes_yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int mimetypes_yychar;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE mimetypes_yylval;
+YYSTYPE mimetypes_yylval YY_INITIAL_VALUE(mimetypes_yyval_default);
 
 /* Number of syntax errors so far.  */
 int mimetypes_yynerrs;
@@ -1291,7 +1271,7 @@ mimetypes_yyparse ()
   int mimetypes_yyn;
   int mimetypes_yyresult;
   /* Lookahead token as an internal (translated) token number.  */
-  int mimetypes_yytoken;
+  int mimetypes_yytoken = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE mimetypes_yyval;
@@ -1309,9 +1289,8 @@ mimetypes_yyparse ()
      Keep to zero when no symbol should be popped.  */
   int mimetypes_yylen = 0;
 
-  mimetypes_yytoken = 0;
-  mimetypes_yyss = mimetypes_yyssa;
-  mimetypes_yyvs = mimetypes_yyvsa;
+  mimetypes_yyssp = mimetypes_yyss = mimetypes_yyssa;
+  mimetypes_yyvsp = mimetypes_yyvs = mimetypes_yyvsa;
   mimetypes_yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1320,14 +1299,6 @@ mimetypes_yyparse ()
   mimetypes_yyerrstatus = 0;
   mimetypes_yynerrs = 0;
   mimetypes_yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  mimetypes_yyssp = mimetypes_yyss;
-  mimetypes_yyvsp = mimetypes_yyvs;
-
   goto mimetypes_yysetstate;
 
 /*------------------------------------------------------------.
@@ -1468,7 +1439,9 @@ mimetypes_yybackup:
   mimetypes_yychar = YYEMPTY;
 
   mimetypes_yystate = mimetypes_yyn;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++mimetypes_yyvsp = mimetypes_yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   goto mimetypes_yynewstate;
 
@@ -1505,8 +1478,7 @@ mimetypes_yyreduce:
   switch (mimetypes_yyn)
     {
         case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 138 "mimetypes.y"
     {
 	     struct rule_tab *p = mimetypes_malloc (sizeof (*p));
@@ -1519,8 +1491,7 @@ mimetypes_yyreduce:
     break;
 
   case 7:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 147 "mimetypes.y"
     {
 	     if (arg_list)
@@ -1531,8 +1502,7 @@ mimetypes_yyreduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 160 "mimetypes.y"
     {
 	     (mimetypes_yyval.string) = mimetypes_append_string2 (&(mimetypes_yyvsp[(1) - (3)].string), '/', &(mimetypes_yyvsp[(3) - (3)].string));
@@ -1540,8 +1510,7 @@ mimetypes_yyreduce:
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 167 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = make_binary_node (L_OR, (mimetypes_yyvsp[(1) - (2)].node), (mimetypes_yyvsp[(2) - (2)].node));
@@ -1549,8 +1518,7 @@ mimetypes_yyreduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 171 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = make_binary_node (L_OR, (mimetypes_yyvsp[(1) - (3)].node), (mimetypes_yyvsp[(3) - (3)].node));
@@ -1558,8 +1526,7 @@ mimetypes_yyreduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 175 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = make_binary_node (L_AND, (mimetypes_yyvsp[(1) - (3)].node), (mimetypes_yyvsp[(3) - (3)].node));
@@ -1567,8 +1534,7 @@ mimetypes_yyreduce:
     break;
 
   case 15:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 181 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = make_negation_node ((mimetypes_yyvsp[(2) - (2)].node));
@@ -1576,8 +1542,7 @@ mimetypes_yyreduce:
     break;
 
   case 16:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 185 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = (mimetypes_yyvsp[(2) - (3)].node);
@@ -1585,8 +1550,7 @@ mimetypes_yyreduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 189 "mimetypes.y"
     {
 	     (mimetypes_yyval.node) = make_suffix_node (&(mimetypes_yyvsp[(1) - (1)].string));
@@ -1594,8 +1558,7 @@ mimetypes_yyreduce:
     break;
 
   case 21:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 200 "mimetypes.y"
     {
 	     reset_lex ();
@@ -1606,8 +1569,7 @@ mimetypes_yyreduce:
     break;
 
   case 22:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 209 "mimetypes.y"
     {
 	     mu_list_create (&arg_list);
@@ -1617,8 +1579,7 @@ mimetypes_yyreduce:
     break;
 
   case 23:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 215 "mimetypes.y"
     {
 	     mu_list_append ((mimetypes_yyvsp[(1) - (3)].list), mimetypes_string_dup (&(mimetypes_yyvsp[(3) - (3)].string)));
@@ -1627,9 +1588,8 @@ mimetypes_yyreduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1633 "mimetypes-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1593 "mimetypes-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter mimetypes_yychar, and that requires
@@ -1792,7 +1752,9 @@ mimetypes_yyerrlab1:
       YY_STACK_PRINT (mimetypes_yyss, mimetypes_yyssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++mimetypes_yyvsp = mimetypes_yylval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
 
   /* Shift the error token.  */
@@ -1858,8 +1820,7 @@ mimetypes_yyreturn:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 224 "mimetypes.y"
 
 
@@ -2346,4 +2307,3 @@ get_file_type ()
   return type;
 }
     
-
